/*----------------------------------------------------------------------- 
 * 
 * File Name: ApplySearch.c
 *
 * Author: Brown, D. A.
 * 
 * Revision: $Id: ApplySearch.c,v 1.1 2001/06/04 04:39:47 duncan Exp $
 * 
 *-----------------------------------------------------------------------
 */

#include "ApplySearch.h"

NRCSID( APPLYSEARCHC, PKG "$Id: ApplySearch.c,v 1.1 2001/06/04 04:39:47 duncan Exp $" );

void
LALApplySearch(
    LALStatus             *status,
    LALSearchOutput       *output,
    LALSearchInput        *input,
    LALApplySearchParams  *applyParams
              )
{
  SimpleSearchParams         *params = NULL;

  INITSTATUS( status, "LALApplySearch", APPLYSEARCHC );
  ATTATCHSTATUSPTR( status );


  /*
   *
   * check output and parameters
   *
   */


  /* check that the output structure exists */
  ASSERT( output, status, APPLYSEARCH_ENULL, APPLYSEARCH_MSGENULL );
  /* and that the results pointer is NULL */
  ASSERT( !(output->result), status, APPLYSEARCH_ENNUL, APPLYSEARCH_MSGENNUL );

  /* in this simple search, we ignore the input to LALApplySearch */
  /* as we already have the data we need stored in the vetor in   */
  /* the parameter structure.                                     */

  /* check the parameter structure */
  ASSERT( applyParams, status, APPLYSEARCH_ENULL, APPLYSEARCH_MSGENULL );
  ASSERT( applyParams->mpiParams, status, 
      APPLYSEARCH_ENULL, APPLYSEARCH_MSGENULL );
  ASSERT( applyParams->searchParams, status, 
      APPLYSEARCH_ENULL, APPLYSEARCH_MSGENULL );

  /* cast the search parameter structure */
  params = (SimpleSearchParams *) applyParams->searchParams;
  

  /*
   *
   * perform the search
   *
   */


  /* normally this would be a more complicated search engine. the simple  */
  /* search counts from 0 to params->maxCount - 1 and returns a number of */
  /* fake inspiral inspiral events determined by the value of             */
  /* params->counter                                                      */

  /* all the nodes do the same thing and report their progress to the     */
  /* wrapperAPI as they proceed.                                          */

  /* on the last call to LALApplySearch(), the original data and          */
  /* conditioned data are returned to the wrapperAPI in the output        */

  /* check to see if the search has finished */
  if ( params->counter < params->maxCount )
  {
    /* we have not yet reached max count, so carry on with the search */

    /* do some kind of search on the data */
    /* LALMySearchFunction()              */

    /* call the fake event generator with the number of events to generate */
    BuildFakeInspiralOutPut( status->statusPtr, output, params->counter + 1 );
    CHECKSTATUSPTR( status );

    /* calculate progress information for the wrapperAPI */
    output->fracRemaining = 1.0 - 
      (REAL4) params->counter / (REAL4) params->maxCount;

    /* we have not yet finished the search */
    output->notFinished  = 1;

    /* increment the progress counter */
    params->counter++;
  }
  else
  {
    /* we are finished with the serach */

    /* put the conditioned data into the optional element in the output */
    BuildOptionalOutPut( status->statusPtr, output, params->dataVec );
    CHECKSTATUSPTR( status );

    /* tell the wrapperAPI we have finished the search */
    output->fracRemaining = 0;
    output->notFinished   = 0;
  }


  /* normal exit */
  DETATCHSTATUSPTR( status );
  RETURN( status );
} 
